import 'package:meta/meta.dart';
import 'package:vegigo2_ui_common/entities/store/delivery_option.dart';
import 'package:vegigo2_ui_common/models/store/time_interval_model.dart';

class DeliveryOptionModel extends DeliveryOption {
  final TimeIntervalModel timeSlot;

  DeliveryOptionModel({
    @required int id,
    DeliveryOptionType type,
    this.timeSlot,
    @required Duration duration
  }) : super(id: id, type: type, timeSlot: timeSlot, duration: duration);

  factory DeliveryOptionModel.fromParent(DeliveryOption deliveryOption) {
    return DeliveryOptionModel(
      id: deliveryOption.id,
      type: deliveryOption.type,
      timeSlot: TimeIntervalModel.fromParent(deliveryOption.timeSlot),
      duration: deliveryOption.duration
    );
  }

  factory DeliveryOptionModel.fromJson(Map<String, dynamic> json) {
    return DeliveryOptionModel(
        id: json['id'] as int,
        type: DeliveryOptionType.values[(json['type'] as int)],
        timeSlot: json['timeSlot'] != null? TimeIntervalModel.fromJson(json['timeSlot'] as Map<String, dynamic>) : null,
        duration: parseDuration(json['duration'] as String)
    );
  }

  Map<String, dynamic> toJson() {
    return {
      'type': type.index,
      'timeSlot': timeSlot != null? timeSlot.toJson() : null,
      'duration': duration.toString()
    };
  }

  static List<DeliveryOptionModel> fromParentArray(List<DeliveryOption> deliveryOptions) {
    return deliveryOptions.map((DeliveryOption option) {
      return DeliveryOptionModel.fromParent(option);
    }).toList();
  }

  static List<DeliveryOptionModel> fromJsonArray(List<dynamic> jsonArray) {
    return jsonArray.map((jsonProduct) => DeliveryOptionModel.fromJson(jsonProduct as Map<String, dynamic>)).toList();
  }

  static List<Map<String, dynamic>> toJsonArray(List<DeliveryOptionModel> deliveryOptions) {
    return deliveryOptions.map((option) => option.toJson()).toList();
  }

  static Duration parseDuration(String durationString) {
    int hours = 0;
    int minutes = 0;
    List<String> parts = durationString.split(':');
    if (parts.length > 2) {
      hours = int.parse(parts[0]);
    }
    if (parts.length > 1) {
      minutes = int.parse(parts[1]);
    }
    return Duration(minutes: minutes + hours * 60);
  }
}