import 'package:flutter/material.dart';
import 'package:vegigo2_ui_common/theme/colors.dart' as colors;

class OutlinedTextField extends StatefulWidget {
  final Key fieldKey;
  final String value;
  final String labelText;
  final double fieldRadius;
  final TextStyle labelStyle;
  final bool hasFloatingLabel;
  final String placeholder;
  final TextStyle placeholderStyle;
  final String prefixText;
  final TextStyle prefixStyle;
  final Icon prefixIcon;
  final String suffixText;
  final TextStyle suffixStyle;
  final IconButton suffixIcon;
  final EdgeInsets contentPadding;
  final bool isDense;
  final bool isObscured;
  final int maxLength;
  final TextInputType inputType;
  final AutovalidateMode autoValidateMode;
  final bool autoFocus;
  final bool readOnly;
  final VoidCallback onTap;
  final FormFieldValidator<String> validator;
  final ValueChanged<String> onChangeHandler;

  OutlinedTextField({
    this.fieldKey,
    this.value,
    this.labelText,
    this.labelStyle,
    this.hasFloatingLabel = false,
    this.fieldRadius = 60.0,
    this.placeholder,
    this.placeholderStyle,
    this.prefixText,
    this.prefixStyle,
    this.prefixIcon,
    this.suffixText,
    this.suffixStyle,
    this.suffixIcon,
    this.contentPadding = const EdgeInsets.all(16.0),
    this.isObscured = false,
    this.isDense = true,
    this.maxLength,
    this.inputType = TextInputType.text,
    this.autoValidateMode = AutovalidateMode.onUserInteraction,
    this.autoFocus = false,
    this.readOnly = false,
    this.validator,
    this.onTap,
    @required this.onChangeHandler
  });

  @override
  _OutlinedTextFieldState createState() => _OutlinedTextFieldState();
}

class _OutlinedTextFieldState extends State<OutlinedTextField> {

  @override
  Widget build(BuildContext context) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        widget.labelText != null && !widget.hasFloatingLabel?
        Padding(
          padding: const EdgeInsets.only(left: 10.0, bottom: 6.0),
          child: Text(widget.labelText,
            style: widget.labelStyle?? Theme.of(context).textTheme.bodyText1.merge(
              TextStyle(fontSize: 14.0, color: Theme.of(context).primaryColor)
            ),
          ),
        ) : Container(),
        TextFormField(
          key: widget.fieldKey,
          readOnly: widget.readOnly,
          obscureText: widget.isObscured,
          maxLength: widget.maxLength,
          autofocus: widget.autoFocus,
          keyboardType: widget.inputType,
          autovalidateMode: widget.autoValidateMode,
          style: _defaultTextStyle,
          decoration: InputDecoration(
            contentPadding: widget.contentPadding,
            border: OutlineInputBorder(
              borderRadius: BorderRadius.circular(widget.fieldRadius),
              borderSide: BorderSide(color: colors.WHITE_1),
            ),
            prefixIcon: widget.prefixIcon,
            prefixText: widget.prefixText,
            prefixStyle: widget.prefixStyle?? _defaultTextStyle,
            suffixIcon: widget.suffixIcon,
            suffixText: widget.suffixText,
            suffixStyle: widget.suffixStyle,
            hintText: widget.placeholder,
            hintStyle: widget.placeholderStyle?? _defaultTextStyle.merge(
              TextStyle(fontSize: 18.0, color: colors.LIGHT_GREY)
            ),
            floatingLabelBehavior: widget.hasFloatingLabel? FloatingLabelBehavior.auto : FloatingLabelBehavior.never,
            isDense: widget.isDense,
          ),
          validator: widget.validator,
          onChanged: widget.onChangeHandler,
          onTap: widget.onTap,
        ),
      ],
    );
  }
  
  TextStyle get _defaultTextStyle {
    return Theme.of(context).textTheme.subtitle1.merge(
      TextStyle(fontSize: 18.0)
    );
  }
}
