import 'package:flutter/material.dart';
import 'package:vegigo2_ui_common/theme/colors.dart' as colors;

class TextFieldWithLabel extends StatefulWidget {
  final Key key;
  final String value;
  final String labelText;
  final double fieldRadius;
  final TextStyle labelStyle;
  final String placeholder;
  final TextStyle placeholderStyle;
  final String prefixText;
  final TextStyle prefixStyle;
  final Icon prefixIcon;
  final String suffixText;
  final TextStyle suffixStyle;
  final Icon suffixIcon;
  final int maxLength;
  final TextInputType inputType;
  final AutovalidateMode autoValidateMode;
  final bool autoFocus;
  final bool readOnly;
  final FormFieldValidator<String> validator;
  final ValueChanged<String> onChangeHandler;

  TextFieldWithLabel({
    this.key,
    this.value,
    this.labelText,
    this.labelStyle,
    this.fieldRadius = 24.0,
    this.placeholder,
    this.placeholderStyle,
    this.prefixText,
    this.prefixStyle,
    this.prefixIcon,
    this.suffixText,
    this.suffixStyle,
    this.suffixIcon,
    this.maxLength,
    this.inputType = TextInputType.text,
    this.autoValidateMode = AutovalidateMode.onUserInteraction,
    this.autoFocus = false,
    this.readOnly = false,
    this.validator,
    @required this.onChangeHandler
  });

  @override
  _TextFieldWithLabelState createState() => _TextFieldWithLabelState();
}

class _TextFieldWithLabelState extends State<TextFieldWithLabel> {

  @override
  Widget build(BuildContext context) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: <Widget>[
        widget.labelText != null?
        Padding(
          padding: const EdgeInsets.only(left: 10.0, bottom: 6.0),
          child: Text(widget.labelText,
            style: widget.labelStyle?? Theme.of(context).textTheme.bodyText1
              .merge(TextStyle(fontSize: 16.0, color: colors.PALE_ORANGE)),
          ),
        ) : Container(),
        TextFormField(
          readOnly: widget.readOnly,
          maxLength: widget.maxLength,
          autofocus: widget.autoFocus,
          keyboardType: widget.inputType,
          autovalidateMode: widget.autoValidateMode,
          style: Theme.of(context).textTheme.headline5.merge(TextStyle(fontSize: 14.0)),
          decoration: InputDecoration(
            border: OutlineInputBorder(
              borderRadius: BorderRadius.circular(widget.fieldRadius),
              borderSide: BorderSide(
                width: 0,
                style: BorderStyle.none,
              ),
            ),
            filled: true,
            fillColor: colors.WHITE_3,
            prefixIcon: widget.prefixIcon,
            prefixText: widget.prefixText,
            prefixStyle: widget.prefixStyle?? Theme.of(context).textTheme.bodyText1
              .merge(TextStyle(fontSize: 14.0)),
            suffixIcon: widget.suffixIcon,
            suffixText: widget.suffixText,
            suffixStyle: widget.suffixStyle,
            hintText: widget.placeholder,
            hintStyle: widget.placeholderStyle?? Theme.of(context).textTheme.bodyText2
              .merge(TextStyle(fontSize: 12.0, color: Colors.black45)),
            floatingLabelBehavior: FloatingLabelBehavior.always,
            isDense: true,
          ),
          validator: widget.validator,
          onChanged: widget.onChangeHandler
        ),
      ],
    );
  }
}
